@@ -1,7 +1,7 @@
 package WWW::Google::Contacts::Contact;
 
 BEGIN {
-    $WWW::Google::Contacts::Contact::VERSION = '0.09';
+    $WWW::Google::Contacts::Contact::VERSION = '0.10';
 }
 
 use Moose;
@@ -396,7 +396,7 @@ WWW::Google::Contacts::Contact
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -474,6 +474,23 @@ If you're just setting the email value, type will default to "work" and leave ot
 
  $contact->email( 'smeghead@reddwarf.net' );
 
+To specify several email addresses, you could either
+
+=over 4
+
+=item * provide them all in an array
+
+ $contact->email([
+    { type => "work", value => 'underpaid@bigcompany.com' },
+    { type => "home", value => 'angryblogger@someblogsite.com' },
+ ]);
+
+=item * call add_email
+
+ $contact->add_email( 'homer@simpson.name' );
+
+=back
+
 =item phone_number
 
 Explicitly setting all phone details:
@@ -487,6 +504,26 @@ Just setting the value will set type to default value "mobile".
 
  $contact->phone_number( "+1666666" );
 
+To specify several phone numbers, you could either
+
+=over 4
+
+=item * provide them all in an array
+
+ $contact->phone_number([
+    { type => "mobile", value => "12345" },
+    { type => "home", value => "666" },
+ ]);
+
+=item * call add_phone_number
+
+ $contact->add_phone_number({
+    type => "home",
+    value => "02078712345"
+ });
+
+=back
+
 =item im
 
 You can specify all IM details:
@@ -530,11 +567,11 @@ the same terms as perl itself.
 
 =item *
 
-Fayland Lam <fayland@gmail.com>
+Magnus Erixzon <magnus@erixzon.com>
 
 =item *
 
-Magnus Erixzon <magnus@erixzon.com>
+Fayland Lam <fayland@gmail.com>
 
 =back
 
