@@ -1,7 +1,8 @@
-package WWW::Google::Contacts::InternalTypes;
+package    # hide from PAUSE
+  WWW::Google::Contacts::InternalTypes;
 
 BEGIN {
-    $WWW::Google::Contacts::InternalTypes::VERSION = '0.09';
+    $WWW::Google::Contacts::InternalTypes::VERSION = '0.10';
 }
 
 use MooseX::Types -declare => [
@@ -48,7 +49,7 @@ WWW::Google::Contacts::InternalTypes
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 AUTHORS
 
@@ -56,11 +57,11 @@ version 0.09
 
 =item *
 
-Fayland Lam <fayland@gmail.com>
+Magnus Erixzon <magnus@erixzon.com>
 
 =item *
 
-Magnus Erixzon <magnus@erixzon.com>
+Fayland Lam <fayland@gmail.com>
 
 =back
 
