@@ -1,7 +1,8 @@
-package WWW::Google::Contacts::Type::Base;
+package    # hide from PAUSE
+  WWW::Google::Contacts::Type::Base;
 
 BEGIN {
-    $WWW::Google::Contacts::Type::Base::VERSION = '0.09';
+    $WWW::Google::Contacts::Type::Base::VERSION = '0.10';
 }
 
 use Moose;
@@ -20,7 +21,7 @@ WWW::Google::Contacts::Type::Base
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 AUTHORS
 
@@ -28,11 +29,11 @@ version 0.09
 
 =item *
 
-Fayland Lam <fayland@gmail.com>
+Magnus Erixzon <magnus@erixzon.com>
 
 =item *
 
-Magnus Erixzon <magnus@erixzon.com>
+Fayland Lam <fayland@gmail.com>
 
 =back
 
