@@ -1,7 +1,8 @@
-package WWW::Google::Contacts::Type::Birthday;
+package    # hide from PAUSE
+  WWW::Google::Contacts::Type::Birthday;
 
 BEGIN {
-    $WWW::Google::Contacts::Type::Birthday::VERSION = '0.09';
+    $WWW::Google::Contacts::Type::Birthday::VERSION = '0.10';
 }
 
 use Moose;
@@ -30,7 +31,7 @@ WWW::Google::Contacts::Type::Birthday
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 AUTHORS
 
@@ -38,11 +39,11 @@ version 0.09
 
 =item *
 
-Fayland Lam <fayland@gmail.com>
+Magnus Erixzon <magnus@erixzon.com>
 
 =item *
 
-Magnus Erixzon <magnus@erixzon.com>
+Fayland Lam <fayland@gmail.com>
 
 =back
 
