@@ -1,7 +1,8 @@
-package WWW::Google::Contacts::Type::Category;
+package    # hide from PAUSE
+  WWW::Google::Contacts::Type::Category;
 
 BEGIN {
-    $WWW::Google::Contacts::Type::Category::VERSION = '0.09';
+    $WWW::Google::Contacts::Type::Category::VERSION = '0.10';
 }
 
 use Moose;
@@ -43,7 +44,7 @@ WWW::Google::Contacts::Type::Category
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 AUTHORS
 
@@ -51,11 +52,11 @@ version 0.09
 
 =item *
 
-Fayland Lam <fayland@gmail.com>
+Magnus Erixzon <magnus@erixzon.com>
 
 =item *
 
-Magnus Erixzon <magnus@erixzon.com>
+Fayland Lam <fayland@gmail.com>
 
 =back
 
