@@ -1,7 +1,8 @@
-package WWW::Google::Contacts::Type::Email;
+package    # hide from PAUSE
+  WWW::Google::Contacts::Type::Email;
 
 BEGIN {
-    $WWW::Google::Contacts::Type::Email::VERSION = '0.09';
+    $WWW::Google::Contacts::Type::Email::VERSION = '0.10';
 }
 
 use Moose;
@@ -69,7 +70,7 @@ WWW::Google::Contacts::Type::Email
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 AUTHORS
 
@@ -77,11 +78,11 @@ version 0.09
 
 =item *
 
-Fayland Lam <fayland@gmail.com>
+Magnus Erixzon <magnus@erixzon.com>
 
 =item *
 
-Magnus Erixzon <magnus@erixzon.com>
+Fayland Lam <fayland@gmail.com>
 
 =back
 
