@@ -1,7 +1,8 @@
-package WWW::Google::Contacts::Type::Gender;
+package    # hide from PAUSE
+  WWW::Google::Contacts::Type::Gender;
 
 BEGIN {
-    $WWW::Google::Contacts::Type::Gender::VERSION = '0.09';
+    $WWW::Google::Contacts::Type::Gender::VERSION = '0.10';
 }
 
 use Moose;
@@ -31,7 +32,7 @@ WWW::Google::Contacts::Type::Gender
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 AUTHORS
 
@@ -39,11 +40,11 @@ version 0.09
 
 =item *
 
-Fayland Lam <fayland@gmail.com>
+Magnus Erixzon <magnus@erixzon.com>
 
 =item *
 
-Magnus Erixzon <magnus@erixzon.com>
+Fayland Lam <fayland@gmail.com>
 
 =back
 
