@@ -1,7 +1,8 @@
-package WWW::Google::Contacts::Type::IM;
+package    # hide from PAUSE
+  WWW::Google::Contacts::Type::IM;
 
 BEGIN {
-    $WWW::Google::Contacts::Type::IM::VERSION = '0.09';
+    $WWW::Google::Contacts::Type::IM::VERSION = '0.10';
 }
 
 use Moose;
@@ -50,7 +51,7 @@ WWW::Google::Contacts::Type::IM
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 AUTHORS
 
@@ -58,11 +59,11 @@ version 0.09
 
 =item *
 
-Fayland Lam <fayland@gmail.com>
+Magnus Erixzon <magnus@erixzon.com>
 
 =item *
 
-Magnus Erixzon <magnus@erixzon.com>
+Fayland Lam <fayland@gmail.com>
 
 =back
 
