@@ -1,7 +1,8 @@
-package WWW::Google::Contacts::Type::Jot;
+package    # hide from PAUSE
+  WWW::Google::Contacts::Type::Jot;
 
 BEGIN {
-    $WWW::Google::Contacts::Type::Jot::VERSION = '0.09';
+    $WWW::Google::Contacts::Type::Jot::VERSION = '0.10';
 }
 
 use Moose;
@@ -42,7 +43,7 @@ WWW::Google::Contacts::Type::Jot
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 AUTHORS
 
@@ -50,11 +51,11 @@ version 0.09
 
 =item *
 
-Fayland Lam <fayland@gmail.com>
+Magnus Erixzon <magnus@erixzon.com>
 
 =item *
 
-Magnus Erixzon <magnus@erixzon.com>
+Fayland Lam <fayland@gmail.com>
 
 =back
 
