@@ -1,7 +1,8 @@
-package WWW::Google::Contacts::Type::Name;
+package    # hide from PAUSE
+  WWW::Google::Contacts::Type::Name;
 
 BEGIN {
-    $WWW::Google::Contacts::Type::Name::VERSION = '0.09';
+    $WWW::Google::Contacts::Type::Name::VERSION = '0.10';
 }
 
 use Moose;
@@ -87,7 +88,7 @@ WWW::Google::Contacts::Type::Name
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 AUTHORS
 
@@ -95,11 +96,11 @@ version 0.09
 
 =item *
 
-Fayland Lam <fayland@gmail.com>
+Magnus Erixzon <magnus@erixzon.com>
 
 =item *
 
-Magnus Erixzon <magnus@erixzon.com>
+Fayland Lam <fayland@gmail.com>
 
 =back
 
