@@ -1,7 +1,8 @@
-package WWW::Google::Contacts::Type::Organization;
+package    # hide from PAUSE
+  WWW::Google::Contacts::Type::Organization;
 
 BEGIN {
-    $WWW::Google::Contacts::Type::Organization::VERSION = '0.09';
+    $WWW::Google::Contacts::Type::Organization::VERSION = '0.10';
 }
 
 use Moose;
@@ -106,7 +107,7 @@ WWW::Google::Contacts::Type::Organization
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 AUTHORS
 
@@ -114,11 +115,11 @@ version 0.09
 
 =item *
 
-Fayland Lam <fayland@gmail.com>
+Magnus Erixzon <magnus@erixzon.com>
 
 =item *
 
-Magnus Erixzon <magnus@erixzon.com>
+Fayland Lam <fayland@gmail.com>
 
 =back
 
