@@ -1,7 +1,8 @@
-package WWW::Google::Contacts::Type::Priority;
+package    # hide from PAUSE
+  WWW::Google::Contacts::Type::Priority;
 
 BEGIN {
-    $WWW::Google::Contacts::Type::Priority::VERSION = '0.09';
+    $WWW::Google::Contacts::Type::Priority::VERSION = '0.10';
 }
 
 use Moose;
@@ -33,7 +34,7 @@ WWW::Google::Contacts::Type::Priority
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 AUTHORS
 
@@ -41,11 +42,11 @@ version 0.09
 
 =item *
 
-Fayland Lam <fayland@gmail.com>
+Magnus Erixzon <magnus@erixzon.com>
 
 =item *
 
-Magnus Erixzon <magnus@erixzon.com>
+Fayland Lam <fayland@gmail.com>
 
 =back
 
