@@ -1,7 +1,8 @@
-package WWW::Google::Contacts::Type::Rel;
+package    # hide from PAUSE
+  WWW::Google::Contacts::Type::Rel;
 
 BEGIN {
-    $WWW::Google::Contacts::Type::Rel::VERSION = '0.09';
+    $WWW::Google::Contacts::Type::Rel::VERSION = '0.10';
 }
 
 use Moose;
@@ -58,7 +59,7 @@ WWW::Google::Contacts::Type::Rel
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 AUTHORS
 
@@ -66,11 +67,11 @@ version 0.09
 
 =item *
 
-Fayland Lam <fayland@gmail.com>
+Magnus Erixzon <magnus@erixzon.com>
 
 =item *
 
-Magnus Erixzon <magnus@erixzon.com>
+Fayland Lam <fayland@gmail.com>
 
 =back
 
