@@ -1,7 +1,8 @@
-package WWW::Google::Contacts::Type::Website;
+package    # hide from PAUSE
+  WWW::Google::Contacts::Type::Website;
 
 BEGIN {
-    $WWW::Google::Contacts::Type::Website::VERSION = '0.09';
+    $WWW::Google::Contacts::Type::Website::VERSION = '0.10';
 }
 
 use Moose;
@@ -61,7 +62,7 @@ WWW::Google::Contacts::Type::Website
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 AUTHORS
 
@@ -69,11 +70,11 @@ version 0.09
 
 =item *
 
-Fayland Lam <fayland@gmail.com>
+Magnus Erixzon <magnus@erixzon.com>
 
 =item *
 
-Magnus Erixzon <magnus@erixzon.com>
+Fayland Lam <fayland@gmail.com>
 
 =back
 
