@@ -1,7 +1,8 @@
-package WWW::Google::Contacts::Type::When;
+package    # hide from PAUSE
+  WWW::Google::Contacts::Type::When;
 
 BEGIN {
-    $WWW::Google::Contacts::Type::When::VERSION = '0.09';
+    $WWW::Google::Contacts::Type::When::VERSION = '0.10';
 }
 
 use Moose;
@@ -40,7 +41,7 @@ WWW::Google::Contacts::Type::When
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 AUTHORS
 
@@ -48,11 +49,11 @@ version 0.09
 
 =item *
 
-Fayland Lam <fayland@gmail.com>
+Magnus Erixzon <magnus@erixzon.com>
 
 =item *
 
-Magnus Erixzon <magnus@erixzon.com>
+Fayland Lam <fayland@gmail.com>
 
 =back
 
