@@ -1,7 +1,8 @@
-package WWW::Google::Contacts::Types;
+package    # hide from PAUSE
+  WWW::Google::Contacts::Types;
 
 BEGIN {
-    $WWW::Google::Contacts::Types::VERSION = '0.09';
+    $WWW::Google::Contacts::Types::VERSION = '0.10';
 }
 
 use MooseX::Types -declare => [
@@ -330,7 +331,7 @@ WWW::Google::Contacts::Types
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 AUTHORS
 
@@ -338,11 +339,11 @@ version 0.09
 
 =item *
 
-Fayland Lam <fayland@gmail.com>
+Magnus Erixzon <magnus@erixzon.com>
 
 =item *
 
-Magnus Erixzon <magnus@erixzon.com>
+Fayland Lam <fayland@gmail.com>
 
 =back
 
